| check_flag_or_scalar_integerish | R Documentation |
This function validates whether the input is either a logical flag
(TRUE/FALSE) or a scalar integer-like value (e.g., 1, 2L, etc.).
check_flag_or_scalar_integerish(x)
x |
The object to check. |
TRUE if the input is a valid flag or scalar integerish, otherwise an error message string.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.