extract_lower_file_extension: Extract Lowercase File Extensions

View source: R/utils.R

extract_lower_file_extensionR Documentation

Extract Lowercase File Extensions

Description

Extracts the file extensions from the provided file paths, normalizes them to lowercase, and returns them as a character vector. The extension includes the leading period (.).

Usage

extract_lower_file_extension(files)

Arguments

files

A character vector of files to search (only for seek_in()).

Value

A character vector of lowercase file extensions.


seekr documentation built on Feb. 8, 2026, 9:06 a.m.